`isotope.search` <-
function(ftlist, mz.tol = 3e-3, fplot = TRUE){

cat("ISOTOPE ANALYSIS:\n", sep = "")
cat("\t- M/Z tolerance:\t",mz.tol,"u\n", sep = "")
Iso <- c(13.00335 - 12, 2*(13.00335 - 12))
Lab <- c("13C#1/12C-isotope","13C#2/12C-isotope")
pl  <- c("(a) ","(b) ")
cat("\t- C12-isotope m/z:\t",12,"u\n", sep = "")
cat("\t- C13#1-isotope m/z:\t",12+Iso[1],"u\n", sep = "")
cat("\t- C13#2-isotope m/z:\t",12+Iso[2],"u\n", sep = "")

isotopes <- matrix(0,dim(ftlist$feature.set)[1],2*(length(Iso)+1))

for (n in 1:length(Iso)){
    index  <- which( abs(ftlist$feature.set[,6]-Iso[n]) < mz.tol )
    C13C12 <- apply(ftlist$data[ftlist$feature.set[index,2],],1,mean)/apply(ftlist$data[ftlist$feature.set[index,1],],1,mean)
    excl   <- which(C13C12>=1)
    incl   <- which(C13C12<1)
    isotopes[index[incl],1]   <- ftlist$feature.set[index[incl],1]
    isotopes[index[incl],n+1] <- ftlist$feature.set[index[incl],2]
    isotopes[index[incl],2+length(Iso)]   <- apply(ftlist$data[ftlist$feature.set[index[incl],1],],1,mean)
    isotopes[index[incl],n+2+length(Iso)] <- apply(ftlist$data[ftlist$feature.set[index[incl],2],],1,mean)
    mz1    <- ftlist$mz[ftlist$feature.set[index[incl],1]]
    mz2    <- ftlist$mz[ftlist$feature.set[index[excl],1]]
    if (length(mz1)>1){
        model <- lm( as.vector(C13C12[incl]) ~ as.vector(mz1))
        cat("\t- ",Lab[n],":\t",length(incl)," feature pairs\n",sep="")
    } else cat("\t- ",Lab[n],":\t",length(incl)," feature pairs\n",sep="")
    if (fplot){
        if (n==1) ge <- split.screen(c(2,1))
        screen(n)
        plot(ftlist$mz[ftlist$feature.set[index,1]],C13C12,cex=1,col="red",xlab="M/Z",ylab="Intensity Ratio",main=paste(pl[n],Lab[n]," ratios (N=",length(incl)," included)",sep=""))
        points(mz1,C13C12[incl],cex=1,col="blue")
        if (length(mz1)>1){
            x  <- seq(min(mz1),max(mz1),length=100)        
            lines(x,model$coefficients[2]*x+model$coefficients[1],col="black",lwd=2)    
            legend("topright",legend=c("EXCLUDED","INCLUDED","L.R."),col = c(2,4,1),lty = c(0,0,1), cex = .8, pch = c(1,1,-1))
        } else legend("topright",legend=c("EXCLUDED","INCLUDED"),col = c(2,4),lty = c(0,0), cex = .8, pch = c(1,1))
        grid()
        if (n==length(Iso)) close.screen(all.screens=TRUE)
    }
}
ftlist$isotopes <- isotopes[which(isotopes[,1]>0),]
colnames(ftlist$isotopes)<-c("Index-12C","Index-13C1","Index-13C2","Intensity-12C","Intensity-13C1","Intensity-13C2")
cat("\t- Total number:\t",dim(ftlist$isotopes)[1]," isotope patterns\n",sep="")

return(ftlist)
}