\name{AStream-package}
\alias{AStream-package}
\alias{AStream}
\docType{package}
\title{AStream: An R package for annotating LC/MS metabolomic feature data}
\description{An R package for the annotation of LC/MS metabolomic data. Identifies isotope, adduct and fragment peaks corresponding to the same molecular compound using 
intensity correlation, retention time and m/z differences between feature pairs.}
\details{
\tabular{ll}{
Package: \tab AStream\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2010-11-28\cr
License: \tab GPL (>=2)\cr
LazyLoad: \tab no\cr
}
}
\author{A.Alonso, et al. Grup de Recerca de Reumatologia 2010, bioinformatics@urr.cat.}
\seealso{\code{\link{xcms.import}}, \code{\link{data.norm}}, \code{\link{isotope.search}}, \code{\link{adduct.search}}, \code{\link{printresults}}, \code{\link{plotcompound}}.}
\examples{
## Analysis of metabolomic LC/MS data from 20 human samples using default parameters

## Load example data
data(astream.data, package = "AStream")

## Normalize intensities, search for outliers and feature pairs selection
feat <- data.norm(input)

## Identify Carbon isotopes
feat <- isotope.search(feat)

## Search for adducts
results  <- adduct.search(feat)

## Save results to file
printresults("results.txt", feat, results)

## Check compound profiles along all samples from any particular identified compound of interest
plotcompound(1, feat, results)
plotcompound(149, feat, results)
plotcompound(209, feat, results)
}
