\name{isotope.search}
\alias{isotope.search}
\title{Method for identifying Carbon isotope patterns}
\description{
Identification of Carbon isotope patterns corresponding to the Carbon-12 and the two first Carbon-13 isotope peaks from the same molecular compound.
}
\usage{
isotope.search(ftlist, mz.tol = 3e-3, fplot = TRUE)
}
\arguments{
  \item{ftlist }{ feature list as returned by \code{\link{data.norm}}.}
  \item{mz.tol }{ tolerance for M/Z values.}
  \item{fplot }{ logical, if \code{'TRUE'} summary figures are plotted.}
}
\details{
\code{isotope.search} returns the same list as the introduced input argurment \code{'ftlist'}. A list of identified 
isotope pattern is added to the list.
}
\value{
  \item{isotopes }{ matrix of isotope patterns is included in the input argument \code{'ftlist'}. Each line is related to a matched isotope pattern.}
}
\author{A.Alonso, et al. Grup de Recerca de Reumatologia 2010, bioinformatics@urr.cat.}
\seealso{\code{\link{xcms.import}}, \code{\link{data.norm}}, \code{\link{adduct.search}}, \code{\link{printresults}}, \code{\link{plotcompound}}.}
\examples{
## Load example data
data(astream.data, package = "AStream")

## Normalize intensities, search for outliers and feature pairs selection
feat <- data.norm(input)

## Identify Carbon isotopes
feat <- isotope.search(feat)

## Show results
feat$isotopes[1:min(15,dim(feat$isotopes)[1]),]
}
