\name{printresults}
\alias{printresults}
\title{Print annotation results}
\description{Extracts and summarizes the metabolite curation results to a tabulated file.}
\usage{printresults(filename, ftlist, results, range = 1e-2, mzsort = FALSE)}
\arguments{
  \item{filename }{ filename where results will be saved.}
  \item{ftlist }{ list returned by \code{\link{isotope.search}}.}
  \item{results }{ matrix returned by \code{\link{adduct.search}}.}
  \item{range }{ m/z tolerance around the identified features m/z for identifying compounds within the Metlin database.}
  \item{mzsort }{ results sorted by m/z.}
}
\references{
  Smith C.A., O'Maille G., Want E.J., Quin C., Trauger S.A., Brandon T.R., Custodio D.E., Abagyan R., Siuzdak G. "METLIN: A Metabolite Mass Spectral Database."
  Therapeutic Drug Monitoring 2005
}
\author{A.Alonso, et al. Grup de Recerca de Reumatologia 2010, bioinformatics@urr.cat.}
\seealso{\code{\link{xcms.import}}, \code{\link{data.norm}}, \code{\link{isotope.search}}, \code{\link{adduct.search}}, \code{\link{plotcompound}}.}
\examples{
## Load example data
data(astream.data, package = "AStream")

## Normalize intensities, search for outliers and feature pairs selection
feat  <- data.norm(input)

## Identify Carbon isotopes
feat  <- isotope.search(feat)

## Search for adducts
results <- adduct.search(feat)

## Save results to file
printresults("results.txt", feat, results)
}